pub fn materialize_manifest_file(
manifest_path: &Path,
out_dir: &Path,
check: bool,
) -> Result<MaterializeSummary, MaterializeError>Expand description
Load a manifest from disk, then materialize or verify it under out_dir.
pub fn materialize_manifest_file(
manifest_path: &Path,
out_dir: &Path,
check: bool,
) -> Result<MaterializeSummary, MaterializeError>Load a manifest from disk, then materialize or verify it under out_dir.