pub fn parse_materialize_manifest_str(
raw: &str,
) -> Result<MaterializeManifest, MaterializeError>Expand description
Parse a manifest string and validate the supported schema.
pub fn parse_materialize_manifest_str(
raw: &str,
) -> Result<MaterializeManifest, MaterializeError>Parse a manifest string and validate the supported schema.